@@ -16,7 +16,7 @@ from .text import *
 __package_name__ = 'pyhelpers'
 __package_name_alt__ = 'PyHelpers'
 __author__ = u'Qian Fu'
-__version__ = '1.2.12'
+__version__ = '1.2.14'
 __email__ = 'qian.fu@outlook.com'
-__description__ = 'An open-source toolkit designed as a miscellaneous collection of simple ' \
-                  'and useful Python tools for facilitating data manipulation tasks.'
+__description__ = \
+    "PyHelpers: an open-source toolkit for facilitating Python users' data manipulation tasks."
